@@ -18,9 +18,9 @@ pub enum ElementType {
     ISize,
     USize,
     String,
-    Object,
     Guid,
     IUnknown,
+    IInspectable,
     HRESULT,
     Matrix3x2,
     TypeName,
@@ -108,7 +108,7 @@ impl ElementType {
             0x18 => Some(Self::ISize),
             0x19 => Some(Self::USize),
             0x0e => Some(Self::String),
-            0x1c => Some(Self::Object),
+            0x1c => Some(Self::IInspectable),
             _ => None,
         }
     }
@@ -126,19 +126,25 @@ impl ElementType {
 
                 match code {
                     TypeDefOrRef::TypeRef(type_ref) => match type_ref.full_name() {
-                        ("System", "Guid") | ("Windows.Win32.Com", "Guid") => Self::Guid,
-                        ("Windows.Win32.Com", "IUnknown") => Self::IUnknown,
+                        ("System", "Guid") => Self::Guid,
+                        ("Windows.Win32.System.Com", "IUnknown") => Self::IUnknown,
                         ("Windows.Foundation", "HResult") => Self::HRESULT,
-                        ("Windows.Win32.Com", "HRESULT") => Self::HRESULT,
-                        ("Windows.Win32.WinRT", "HSTRING") => Self::String,
-                        ("Windows.Win32.WinRT", "IInspectable") => Self::Object,
-                        ("Windows.Win32.SystemServices", "LARGE_INTEGER") => Self::I64,
-                        ("Windows.Win32.SystemServices", "ULARGE_INTEGER") => Self::U64,
-                        ("Windows.Win32.Direct2D", "D2D_MATRIX_3X2_F") => Self::Matrix3x2,
+                        ("Windows.Win32.System.Com", "HRESULT") => Self::HRESULT,
+                        ("Windows.Win32.System.WinRT", "HSTRING") => Self::String,
+                        ("Windows.Win32.System.WinRT", "IInspectable") => Self::IInspectable,
+                        ("Windows.Win32.System.SystemServices", "LARGE_INTEGER") => Self::I64,
+                        ("Windows.Win32.System.SystemServices", "ULARGE_INTEGER") => Self::U64,
+                        ("Windows.Win32.Graphics.Direct2D", "D2D_MATRIX_3X2_F") => Self::Matrix3x2,
                         ("System", "Type") => Self::TypeName,
                         _ => Self::from_type_def(type_ref.resolve(), Vec::new()),
                     },
-                    TypeDefOrRef::TypeDef(type_def) => Self::from_type_def(type_def, Vec::new()),
+                    TypeDefOrRef::TypeDef(type_def) => Self::from_type_def(
+                        // Need to "re-resolve" the TypeDef as it may point to an arch-specific
+                        // definition. This lets the TypeTree be built for a specific architecture
+                        // without accidentally pulling in the wrong definition.
+                        TypeReader::get().resolve_type_def(type_def.namespace(), type_def.name()),
+                        Vec::new(),
+                    ),
                     _ => unexpected!(),
                 }
             }
@@ -204,10 +210,10 @@ impl ElementType {
             Self::ISize => quote! { isize },
             Self::USize => quote! { usize },
             Self::String => {
-                quote! { ::windows::HString }
+                quote! { ::windows::HSTRING }
             }
-            Self::Object => {
-                quote! { ::windows::Object }
+            Self::IInspectable => {
+                quote! { ::windows::IInspectable }
             }
             Self::Guid => {
                 quote! { ::windows::Guid }
@@ -261,7 +267,7 @@ impl ElementType {
             Self::String => {
                 quote! { ::windows::RawPtr }
             }
-            Self::Object => {
+            Self::IInspectable => {
                 quote! { ::windows::RawPtr }
             }
             Self::Guid => {
@@ -346,7 +352,7 @@ impl ElementType {
             Self::F32 => "f4".to_owned(),
             Self::F64 => "f8".to_owned(),
             Self::String => "string".to_owned(),
-            Self::Object => "cinterface(IInspectable)".to_owned(),
+            Self::IInspectable => "cinterface(IInspectable)".to_owned(),
             Self::Guid => "g16".to_owned(),
             Self::Class(t) => t.type_signature(),
             Self::Interface(t) => t.type_signature(),
@@ -393,7 +399,7 @@ impl ElementType {
     pub fn is_nullable(&self) -> bool {
         matches!(
             self,
-            Self::Object
+            Self::IInspectable
                 | Self::IUnknown
                 | Self::Function(_)
                 | Self::Interface(_)
@@ -407,7 +413,7 @@ impl ElementType {
     pub fn is_blittable(&self) -> bool {
         match self {
             Self::String
-            | Self::Object
+            | Self::IInspectable
             | Self::IUnknown
             | Self::GenericParam(_)
             | Self::Class(_)
@@ -424,7 +430,7 @@ impl ElementType {
         matches!(
             self,
             Self::String
-                | Self::Object
+                | Self::IInspectable
                 | Self::Guid
                 | Self::IUnknown
                 | Self::Matrix3x2
@@ -497,8 +503,8 @@ impl ElementType {
             Self::Delegate(t) => t.gen(gen),
             Self::Callback(t) => t.gen(gen),
             Self::GenericParam(p) => p.gen_name(),
-            Self::Object => {
-                quote! { ::windows::Object }
+            Self::IInspectable => {
+                quote! { ::windows::IInspectable }
             }
             _ => unexpected!(),
         }
@@ -521,7 +527,8 @@ mod tests {
 
     #[test]
     fn test_struct() {
-        let t = TypeReader::get().resolve_type("Windows.Win32.Dxgi", "DXGI_FRAME_STATISTICS_MEDIA");
+        let t = TypeReader::get()
+            .resolve_type("Windows.Win32.Graphics.Dxgi", "DXGI_FRAME_STATISTICS_MEDIA");
         let d = t.definition();
         assert_eq!(d.len(), 1);
         assert_eq!(d[0].name(), "DXGI_FRAME_STATISTICS_MEDIA");
@@ -533,8 +540,10 @@ mod tests {
 
     #[test]
     fn test_enum() {
-        let t =
-            TypeReader::get().resolve_type("Windows.Win32.Dxgi", "DXGI_FRAME_PRESENTATION_MODE");
+        let t = TypeReader::get().resolve_type(
+            "Windows.Win32.Graphics.Dxgi",
+            "DXGI_FRAME_PRESENTATION_MODE",
+        );
         let d = t.definition();
         assert_eq!(d.len(), 1);
         assert_eq!(d[0].name(), "DXGI_FRAME_PRESENTATION_MODE");
@@ -545,7 +554,7 @@ mod tests {
 
     #[test]
     fn test_com_interface() {
-        let t = TypeReader::get().resolve_type("Windows.Win32.Direct2D", "ID2D1Resource");
+        let t = TypeReader::get().resolve_type("Windows.Win32.Graphics.Direct2D", "ID2D1Resource");
         let d = t.definition();
         assert_eq!(d.len(), 1);
         assert_eq!(d[0].name(), "ID2D1Resource");
@@ -595,7 +604,8 @@ mod tests {
 
     #[test]
     fn test_win32_function() {
-        let t = TypeReader::get().resolve_type("Windows.Win32.WindowsAndMessaging", "EnumWindows");
+        let t =
+            TypeReader::get().resolve_type("Windows.Win32.UI.WindowsAndMessaging", "EnumWindows");
         assert_eq!(t.definition().len(), 0);
 
         let mut d = t.dependencies();
@@ -610,14 +620,16 @@ mod tests {
 
     #[test]
     fn test_win32_constant() {
-        let t = TypeReader::get().resolve_type("Windows.Win32.Dxgi", "DXGI_USAGE_SHADER_INPUT");
+        let t = TypeReader::get()
+            .resolve_type("Windows.Win32.Graphics.Dxgi", "DXGI_USAGE_SHADER_INPUT");
         assert_eq!(t.definition().len(), 0);
         assert_eq!(t.dependencies().len(), 0);
     }
 
     #[test]
     fn test_win32_callback() {
-        let t = TypeReader::get().resolve_type("Windows.Win32.WindowsAndMessaging", "WNDENUMPROC");
+        let t =
+            TypeReader::get().resolve_type("Windows.Win32.UI.WindowsAndMessaging", "WNDENUMPROC");
         let d = t.definition();
         assert_eq!(d.len(), 1);
         assert_eq!(d[0].name(), "WNDENUMPROC");
