@@ -71,32 +71,40 @@ impl TypeReader {
                     continue;
                 }
 
-                if extends == ("", "") {
-                    continue;
-                }
+                match extends {
+                    ("System", "Object") => {
+                        for field in def.fields() {
+                            let name = field.name();
 
-                if extends != ("System", "Object") {
-                    continue;
-                }
+                            types
+                                .entry(namespace)
+                                .or_default()
+                                .entry(name)
+                                .or_insert_with(|| TypeRow::Constant(field));
+                        }
 
-                for field in def.fields() {
-                    let name = field.name();
+                        for method in def.methods() {
+                            let name = method.name();
 
-                    types
-                        .entry(namespace)
-                        .or_default()
-                        .entry(name)
-                        .or_insert_with(|| TypeRow::Constant(field));
-                }
+                            types
+                                .entry(namespace)
+                                .or_default()
+                                .entry(name)
+                                .or_insert_with(|| TypeRow::Function(method));
+                        }
+                    }
+                    ("System", "Enum") => {
+                        for field in def.fields() {
+                            let name = field.name();
 
-                for method in def.methods() {
-                    let name = method.name();
-
-                    types
-                        .entry(namespace)
-                        .or_default()
-                        .entry(name)
-                        .or_insert_with(|| TypeRow::Function(method));
+                            types
+                                .entry(namespace)
+                                .or_default()
+                                .entry(name)
+                                .or_insert_with(|| TypeRow::Constant(field));
+                        }
+                    }
+                    _ => {}
                 }
             }
 
@@ -114,13 +122,13 @@ impl TypeReader {
 
         let exclude = &[
             ("Windows.Foundation", "HResult"),
-            ("Windows.Win32.Com", "HRESULT"),
-            ("Windows.Win32.Com", "IUnknown"),
-            ("Windows.Win32.WinRT", "HSTRING"),
-            ("Windows.Win32.WinRT", "IActivationFactory"),
-            ("Windows.Win32.Direct2D", "D2D_MATRIX_3X2_F"),
-            ("Windows.Win32.SystemServices", "LARGE_INTEGER"),
-            ("Windows.Win32.SystemServices", "ULARGE_INTEGER"),
+            ("Windows.Win32.System.Com", "HRESULT"),
+            ("Windows.Win32.System.Com", "IUnknown"),
+            ("Windows.Win32.System.WinRT", "HSTRING"),
+            ("Windows.Win32.System.WinRT", "IActivationFactory"),
+            ("Windows.Win32.Graphics.Direct2D", "D2D_MATRIX_3X2_F"),
+            ("Windows.Win32.System.SystemServices", "LARGE_INTEGER"),
+            ("Windows.Win32.System.SystemServices", "ULARGE_INTEGER"),
         ];
 
         for (namespace, name) in exclude {
@@ -136,7 +144,7 @@ impl TypeReader {
         self.types
             .keys()
             .find(|namespace| *namespace == &find)
-            .expect(&format!("Could not find namespace `{}`", find))
+            .unwrap_or_else(|| panic!("Could not find namespace `{}`", find))
     }
 
     /// Get all the namespace names that the [`TypeReader`] knows about
@@ -149,10 +157,7 @@ impl TypeReader {
     /// # Panics
     ///
     /// Panics if the namespace does not exist
-    pub fn namespace_types(
-        &'static self,
-        namespace: &str,
-    ) -> impl Iterator<Item = ElementType> + '_ {
+    pub fn namespace_types(&'static self, namespace: &str) -> impl Iterator<Item = ElementType> {
         self.types[namespace]
             .values()
             .map(move |row| self.to_element_type(row))
@@ -178,6 +183,28 @@ impl TypeReader {
         panic!("Could not find type `{}.{}`", namespace, name);
     }
 
+    pub fn get_namespace(&'static self, namespace: &str) -> Option<&'static str> {
+        if let Some((namespace, _)) = self.types.get_key_value(namespace) {
+            Some(namespace)
+        } else {
+            None
+        }
+    }
+
+    pub fn get_type_name(
+        &'static self,
+        namespace: &str,
+        name: &str,
+    ) -> Option<(&'static str, &'static str)> {
+        if let Some((namespace, types)) = self.types.get_key_value(namespace) {
+            if let Some((name, _)) = types.get_key_value(trim_tick(name)) {
+                return Some((namespace, name));
+            }
+        }
+
+        None
+    }
+
     fn to_element_type(&'static self, row: &TypeRow) -> ElementType {
         match row {
             TypeRow::TypeDef(row) => ElementType::from_type_def(*row, Vec::new()),
